package com.theitbulls.pushnotification.fcmservice;

import android.app.ProgressDialog;
import android.content.Context;
import android.provider.Settings;
import android.util.Log;
import android.view.View;

import com.android.volley.Request;
import com.android.volley.Response;
import com.android.volley.RetryPolicy;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.JsonObjectRequest;
import com.android.volley.toolbox.StringRequest;
import com.theitbulls.pushnotification.VolleyInstance;
import com.theitbulls.pushnotification.utils.DialogUtils;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;

public class FCMUtils {
    // for emulator
    // public static final String BASE_URL = "http://10.0.2.2:8080/fcm";

    public static final String BASE_URL = "https://example.com/fcm";

    public static void sendDataNotification(final Context mContext, JSONObject jsonData) {
        final ProgressDialog progressDialog = new ProgressDialog(mContext);
        progressDialog.setMessage("Sending FCM data notification...");
        progressDialog.show();

        String token = SharedPrefManager.getInstance(mContext).getDeviceTokenString();
        String url = BASE_URL + "?type=" + 1 + "&token=" + token;
        JsonObjectRequest jsonRequest = new JsonObjectRequest(url, jsonData, new Response.Listener<JSONObject>() {
            @Override
            public void onResponse(JSONObject response) {
                progressDialog.dismiss();

                String result = response.toString();
                Log.d("FCMStatus", result);
                DialogUtils.msgToast(mContext, result);
            }

        }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                progressDialog.dismiss();

                Log.d("FCMError", error.toString());
                DialogUtils.msgToast(mContext, error.toString());
            }
        });

        VolleyInstance.getInstance(mContext).addToRequestQueue(jsonRequest);
    }

    public static void sendNotification(final Context mContext, final String title, final String msg) {
        final ProgressDialog progressDialog = new ProgressDialog(mContext);
        progressDialog.setMessage("Sending FCM Notification...");
        progressDialog.show();

        String token = SharedPrefManager.getInstance(mContext).getDeviceTokenString();
        String url = BASE_URL + "?type=" + 0 + "&token=" + token;
        StringRequest stringRequest = new StringRequest(Request.Method.POST, url, new Response.Listener<String>() {
            @Override
            public void onResponse(String response) {
                progressDialog.dismiss();
                try {
                    JSONObject obj = new JSONObject(response);
                    Log.d("FCMStatus", response);
                    DialogUtils.msgToast(mContext, response);
                } catch (JSONException e) {
                    Log.d("FCMError", e.toString());
                    DialogUtils.msgToast(mContext, e.toString());
                }
            }
        }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                progressDialog.dismiss();
                DialogUtils.msgToast(mContext, error.getMessage());
            }
        }) {
            @Override
            protected Map<String, String> getParams() {
                Map<String, String> params = new HashMap<>();

                params.put("msg", msg);
                params.put("title", title);
                return params;
            }
        };

        addRetryPolicy(stringRequest);
        VolleyInstance.getInstance(mContext).addToRequestQueue(stringRequest);
    }

    public void register(final Context mContext, View view) {
        final ProgressDialog progressDialog = new ProgressDialog(mContext);
        progressDialog.setMessage("Registering Device...");
        progressDialog.show();

        final String token = SharedPrefManager.getInstance(mContext).getDeviceTokenString();
        if (token == null) {
            progressDialog.dismiss();
            DialogUtils.msgToast(mContext, "token error!!");
            return;
        }

        StringRequest httpReq = new StringRequest(Request.Method.POST, "http://", new Response.Listener<String>() {
            @Override
            public void onResponse(String response) {
                progressDialog.dismiss();
                try {
                    JSONObject obj = new JSONObject(response);
                    DialogUtils.msgToast(mContext, response);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
        }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                progressDialog.dismiss();
                DialogUtils.msgToast(mContext, error.getMessage());
            }
        }) {
            @Override
            protected Map<String, String> getParams() {
                Map<String, String> params = new HashMap<>();
                params.put("type", "type");

                String fcmToken = SharedPrefManager.getInstance(mContext).getDeviceTokenString();
                String droidId = Settings.Secure.getString(mContext.getContentResolver(), Settings.Secure.ANDROID_ID);
                params.put("user_id", String.valueOf(12));
                params.put("u_user_id", String.valueOf(12));

                params.put("fcm_token", fcmToken);
                params.put("device_id", droidId);
                params.put("orgId", String.valueOf(1));
                params.put("mnuId", String.valueOf(112));
                return params;
            }
        };
        VolleyInstance.getInstance(mContext).addToRequestQueue(httpReq);
    }

    private static void addRetryPolicy(StringRequest stringRequest) {
        stringRequest.setRetryPolicy(new RetryPolicy() {
            @Override
            public int getCurrentTimeout() {
                return 500000;
            }

            @Override
            public int getCurrentRetryCount() {
                return 500000;
            }

            @Override
            public void retry(VolleyError error) {

            }
        });
    }
}
