package com.theitbulls.pushnotification.fcmservice;

import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.os.Build;
import android.util.Log;

import androidx.core.app.NotificationCompat;
import androidx.core.app.NotificationManagerCompat;

import com.google.firebase.messaging.FirebaseMessagingService;
import com.google.firebase.messaging.RemoteMessage;
import com.theitbulls.pushnotification.R;

import java.util.Map;
import java.util.Set;

public class MyFirebaseMessagingService extends FirebaseMessagingService {
    private static final String LOG_TAG = "FCMResult";
    private static final int NOTIFICATION_ID = 0x34;

    @Override
    public void onMessageReceived(RemoteMessage remoteMessage) {
        RemoteMessage.Notification notification = remoteMessage.getNotification();

        if (notification != null) {
            // for getting notification information
            String title = remoteMessage.getNotification().getTitle();
            String message = remoteMessage.getNotification().getBody();
            String icon = remoteMessage.getNotification().getIcon();

            sendPushNotification(title, message);
            Log.d("FCMNotification", title + ": " + message + ": " + icon + ": " + remoteMessage.getData());
        }

        Map<String, String> data = remoteMessage.getData();
        if (!data.isEmpty()) {
            // for getting data notification information
            String result = "";
            Set<String> keys = data.keySet();
            for (String key : keys) {
                result += key + ":" + data.get(key) + ", ";
            }

            Log.d("FCMDataMessage", result);
        }
        // Log.d("FCMData", (notification == null) + " : " + data.size());
    }

    private void sendPushNotification(String title, String message) {
        NotificationCompat.Builder mBuilder = new NotificationCompat.Builder(this, MyNotificationManager.NOTIFICATION_CHANNEL_ID)
                .setSmallIcon(R.mipmap.ic_launcher)
                .setContentTitle(title)
                .setContentText(message)
                .setPriority(NotificationCompat.PRIORITY_DEFAULT);

        createNotificationChannel(mBuilder);
    }

    private void createNotificationChannel(NotificationCompat.Builder mBuilder) {
        // Create the NotificationChannel, but only on API 26+ because
        // the NotificationChannel class is new and not in the support library
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            CharSequence name = "My FCM Channel";
            String description = "This channel is demo of FCM";

            int importance = NotificationManager.IMPORTANCE_DEFAULT;

            NotificationChannel channel = new NotificationChannel(MyNotificationManager.NOTIFICATION_CHANNEL_ID, name, importance);
            channel.setDescription(description);
            // Register the channel with the system; you can't change the importance
            // or other notification behaviors after this
            NotificationManager notificationManager = getSystemService(NotificationManager.class);
            notificationManager.createNotificationChannel(channel);
        }

        NotificationManagerCompat notificationManager = NotificationManagerCompat.from(this);
        // NOTIFICATION_ID is a unique int for each notification that you must define
        notificationManager.notify(NOTIFICATION_ID, mBuilder.build());
    }
}
